==> order-center-api-3.2.2-CLOUD-TEST-20240722.072727-8-sources.jar: com/tydic/dyc/oc/constants/UocAttachementTypeConstants.java <==
package com.tydic.dyc.oc.constants;

/**
 * 标题:UocAttachementTypeConstants
 * 说明:附件类型常量
 * 时间:2022/3/10 15:19
 * 作者:田桂银
 */
public class UocAttachementTypeConstants {

    /*
      订单创建 1001
      销售单取消 1002
      销售单取消申请 1003
      销售单取消申请同意 1004
      销售单取消申请拒绝 1005
      销售单接单 1006
      销售单拒单 1007
      执行单发货 1008
      到货登记 1009
      到货确认 1010
      到货拒收 1011
      到货验收 1012
      到货验收其它验收 1013
      过磅信息
     */

    /**
     * 订单创建 1001
     */
    public static final Integer CREATE_ORDER = 1001;
    /**
     * 销售单取消
     */
    public static final Integer CANCEL_SALE_ORDER = 1002;
    /**
     * 销售单取消申请
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER = 1003;
    /**
     * 销售单取消申请同意
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER_CONFIRM = 1004;
    /**
     * 销售单取消申请拒绝
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER_REJECT = 1005;
    /**
     * 销售单接单
     */
    public static final Integer SALE_ORDER_TAKE = 1006;
    /**
     * 销售单拒单
     */
    public static final Integer SALE_ORDER_REJECT = 1007;
    /**
     * 执行单发货
     */
    public static final Integer DELIVERY = 1008;
    /**
     * 到货登记
     */
    public static final Integer ARRIVAL_REGIST = 1009;
    /**
     * 到货确认
     */
    public static final Integer ARRIVAL_CONFIRM = 1010;
    /**
     * 到货拒收
     */
    public static final Integer ARRIVAL_REFUSE = 1011;
    /**
     * 到货验收
     */
    public static final Integer ACCEPTANCE = 1012;
    /**
     * 到货验收其它验收(验收报告）
     */
    public static final Integer ACCEPTANCE_OTHER = 1013;
    /**
     * 验收照片
     */
    public static final Integer ACCEPTANCE_PICTURE = 1014;
    /**
     * 立项依据材料
     */
    public static final Integer PROJECT_APPROVAL_MATERIAL = 1015;
    /**
     * 未比选原因附件
     */
    public static final Integer NO_CMP_REASON_ACCESS = 1016;
    /**
     * 收货地址附件
     */
    public static final Integer SHIP_ADDRESS_ACCESS = 1017;
    /**
     * 发票信息附件
     */
    public static final Integer INVOICE_ACCESS = 1018;

    /**
     * 京能 oa 审批结果
     */
    public static final Integer OA_APPROVAL_RESULT = 1019;

    /**
     * 过磅信息
     */
    public static final Integer AGR_ITEM_WEIGHT = 1020;
}

==> order-center-api-3.2.4-CLOUD-TEST-20240827.085809-5-sources.jar: com/tydic/dyc/oc/constants/UocAttachementTypeConstants.java <==
package com.tydic.dyc.oc.constants;

/**
 * 标题:UocAttachementTypeConstants
 * 说明:附件类型常量
 * 时间:2022/3/10 15:19
 * 作者:田桂银
 */
public class UocAttachementTypeConstants {

    /*
      订单创建 1001
      销售单取消 1002
      销售单取消申请 1003
      销售单取消申请同意 1004
      销售单取消申请拒绝 1005
      销售单接单 1006
      销售单拒单 1007
      执行单发货 1008
      到货登记 1009
      到货确认 1010
      到货拒收 1011
      到货验收 1012
      到货验收其它验收 1013
     */

    /**
     * 订单创建 1001
     */
    public static final Integer CREATE_ORDER = 1001;
    /**
     * 销售单取消
     */
    public static final Integer CANCEL_SALE_ORDER = 1002;
    /**
     * 销售单取消申请
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER = 1003;
    /**
     * 销售单取消申请同意
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER_CONFIRM = 1004;
    /**
     * 销售单取消申请拒绝
     */
    public static final Integer CANCEL_APPLY_SALE_ORDER_REJECT = 1005;
    /**
     * 销售单接单
     */
    public static final Integer SALE_ORDER_TAKE = 1006;
    /**
     * 销售单拒单
     */
    public static final Integer SALE_ORDER_REJECT = 1007;
    /**
     * 执行单发货
     */
    public static final Integer DELIVERY = 1008;
    /**
     * 到货登记
     */
    public static final Integer ARRIVAL_REGIST = 1009;
    /**
     * 到货确认
     */
    public static final Integer ARRIVAL_CONFIRM = 1010;
    /**
     * 到货拒收
     */
    public static final Integer ARRIVAL_REFUSE = 1011;
    /**
     * 到货验收
     */
    public static final Integer ACCEPTANCE = 1012;
    /**
     * 到货验收其它验收(验收报告）
     */
    public static final Integer ACCEPTANCE_OTHER = 1013;
    /**
     * 验收照片
     */
    public static final Integer ACCEPTANCE_PICTURE = 1014;
    /**
     * 立项依据材料
     */
    public static final Integer PROJECT_APPROVAL_MATERIAL = 1015;
    /**
     * 未比选原因附件
     */
    public static final Integer NO_CMP_REASON_ACCESS = 1016;
    /**
     * 收货地址附件
     */
    public static final Integer SHIP_ADDRESS_ACCESS = 1017;
    /**
     * 发票信息附件
     */
    public static final Integer INVOICE_ACCESS = 1018;
    /**
     * 应急订单附件
     */
    public static final Integer EMMERTGENCY_ORDER = 1019;
    /**
     * 框架协议订单附件
     */
    public static final Integer AGR_ORDER = 1020;
}
